@@ -104,6 +104,13 @@ DomainSchema = build_schema({
     }
 })
 
+# a bucket for any kinds of misc settings a Job might need
+JobsettingsSchema = build_schema({
+    "properties": {
+        F.JOB_SETTINGS: {"type": "object"},
+    }
+})
+
 GeoipSchema = build_schema({
     "properties": {
         F.GEOIP: {
@@ -232,6 +239,13 @@ UrlSchema = build_schema({
     }
 })
 
+VirustotalSchema = build_schema({
+    "properties": {
+        F.VIRUSTOTAL_RESULT: {"type": ["object", "null"]},
+        F.HTTP_STATUS: {"type": ["number", "null"]},
+    }
+})
+
 WebfingerprintsSchema = build_schema({
     "properties": {
         F.WEB_FINGERPRINTS: {
